OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Bonjour %s",
    "Hello %s," : "Bonjour %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Nouvelle notification pour %s","%n nouvelles notifications pour %s","%n nouvelles notifications pour %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Vous avez une nouvelle notification pour %s","Vous avez %n nouvelles notifications pour %s","Vous avez %n nouvelles notifications pour %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les <a href=\"%s\">paramètres</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les paramètres : %s",
    "Admin notifications" : "Notifications d'administration",
    "Notifications" : "Notifications",
    "Push notifications - Fair use policy" : "Notifications push - Politique d'utilisation équitable",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsorise une passerelle de notification push gratuite pour les utilisateurs privés. Pour assurer un bon service, la passerelle limite le nombre de notifications push par serveur et la limite a été atteinte pour ce serveur. Pour les utilisateurs professionnels, une passerelle plus modulable est disponible.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Cette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "\tCette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.\n📬 Partage de fichiers fédérés: vous avez reçu un nouveau partage distant\n\n📑 Commentaires: Un autre utilisateur vous a mentionné dans un commentaire sur un fichier.\n\n🚢 Notification de mise à jour: mise à jour disponible pour une application ou nextcloud elle-même.\n\n📣 Centre d'annonces: Une annonce a été publiée par un administrateur",
    "Failed to perform action" : "Échec lors de la réalisation de l'action",
    "Dismiss" : "Ignorer",
    "Contact Nextcloud GmbH" : "Contacter Nextcloud GmbH",
    "seconds ago" : "à l'instant",
    "Failed to dismiss notification" : "Impossible d'ignorer la notification",
    "in {path}" : "dans {path}",
    "Dismiss all notifications" : "Ignorer toutes les notifications",
    "Requesting browser permissions to show notifications" : "Nécessite les autorisations du navigateur pour afficher les notifications",
    "Push notifications might be unreliable" : "Les notifications push peuvent ne pas être fiables",
    "No notifications" : "Aucune notification",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud Gmbh sponsorise une passerelle de notification push gratuite pour les utilisateurs individuels. Afin d'assurer la qualité du service, la passerelle limite le nombre de notifications push par serveur. Pour les utilisateurs professionnels, une passerelle plus évolutive est disponible. Veuillez contacter Nextcloud Gmbh pour plus d'informations.",
    "Failed to dismiss all notifications" : "Impossible d'ignorer toutes les notifications",
    "Notifications defaults" : "Paramètres de notification par défaut",
    "Configure the default notification settings for new users" : "Configurez les paramètres de notification par défaut pour les nouveaux utilisateurs.",
    "Send email reminders about unhandled notifications after:" : "Envoyer par e-mail des rappels des notifications non gérées après :",
    "Play sound when a new notification arrives" : "Jouer un son quand une notification arrive",
    "Play sound when a call started (requires Nextcloud Talk)" : "Jouer un son quand un appel démarre (l'application Nextcloud Talk est requise)",
    "Never" : "Jamais",
    "1 hour" : "1 heure",
    "3 hours" : "3 heures",
    "1 day" : "1 jour",
    "1 week" : "1 semaine",
    "Your settings have been updated." : "Vos paramètres ont été mis à jour.",
    "An error occurred while updating your settings." : "Un erreur est survenue lors de la mise à jour de vos paramètres.",
    "You need to set up your email address before you can receive notification emails." : "Vous devez définir votre adresse e-mail avant de pouvoir recevoir des e-mails de notification."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
